@@ -334,7 +334,7 @@ Legato.Format.ExtendedWMCLoader = Legato.Lang
         OpenLayers.loadURL(this.url, this.params, this, onSuccess,
             onFailure);
       },
-      synchronize : function() {
+      synchronize : function(onSuccessCallback, onFailureCallback) {
 
         var onSuccess = function(request) {
           try {
@@ -394,6 +394,9 @@ Legato.Format.ExtendedWMCLoader = Legato.Lang
             if (needsSynchronization) {
               this.map.events.triggerEvent("legato.refresh", {});
             }
+            if(Legato.Lang.ObjectUtils.isFunction(onSuccessCallback)){
+              onSuccessCallback();
+            }
           } catch (e) {
             Legato.Util.Logger.getLogger().error(
                 'Could not parse synchronize viewcontext response ['
@@ -407,6 +410,9 @@ Legato.Format.ExtendedWMCLoader = Legato.Lang
           Legato.Util.Logger.getLogger().error(
               'Could not synchronize viewcontext [' + this.url
                   + '] with params ' + this.params);
+          if(Legato.Lang.ObjectUtils.isFunction(onFailureCallback)){
+            onFailureCallback();
+          }
         };
 
         // Do the actual call.
